## Analysis file for replicating analyses from Miles, Andrew. 2015. "The (Re)genesis of Values: Examining the Importance of Values for Action." American Sociological Review ??(??):??

#set this filepath to point to the folder that contains all of the analysis files for this paper, plus the ESS data files
setwd("FILE PATH TO FOLDER HERE")
#NOTE: ESS data, round 2, can be downloaded from http://www.europeansocialsurvey.org/download.html?file=ESS2e03_4&y=2004
#NOTE: the version of the data file that I used is the SPSS format, file ESS2e03_3.sav - current data files might differ slightly
#if you download the SAS or STATA versions, you will need to use different commands to import the data, e.g., read.dta() instead of read.spss()

##load project-specific functions that you will need
source("Miles 2015 - V&A - functions.R")
## Read in ESS data, impute it, code it
#NOTE: this section of code takes quite a while to run, often 1-2 hours
source("Miles 2015 - V&A - ESS data coding.R")

#you might want to save the data at this point to avoid having to re-run the code above every time you want to run analyses
#save.image(file="data_imputed.rdata")
#load it in like this
#load(file="data_imputed.rdata)

#load required packages
library(mitools); library(multilevel); library(Amelia); library(ordinal); library(psych); library(Hmisc); library(MASS); library(spatstat); library(plotrix)

#read in data
#load(file="~/Documents/Duke/Values and action paper/ESS analyses/ESSimputed_bycountry_nocntrydummies.rdata")

#put imputed data into an imputation list
implist=imputationList(impdata$imputations)
#ordinal version of social variable for analyses
implist$imputations = lapply(implist$imputations, function(x) {x$social.fac = factor(round(x$social)); return(x)})
d$social.fac = factor(d$social)
#convenience variable used throughout
printnums = seq(from=0, to=length(implist$imputations), by=10)

###########################################################
# DESCRIPTIVE INFORMATION
###########################################################
#Cronbach's alpha for value dimensions

#self-transcendence
x=with(implist, cronbach(cbind(iphlppl, iplylfr, ipeqopt, ipudrst, impenv, -imprich, -iprspot, -ipshabt, -ipsuces))$Alpha)
MIcombine2(x)

x=with(implist, cronbach(cbind(-ipgdtim, -impfun, -impdiff, -ipadvnt, -ipcrtiv, -impfree, impsafe, ipstrgv, ipfrule, ipbhprp, ipmodst, imptrad))$Alpha)
MIcombine2(x)

#factor loadings for values measures 
#see footnote 5 here: http://essedunet.nsd.uib.no/cms/topics/1/4/4.html
famods=lapply(implist$imputations, function(x) {with(x, fa(cbind(ipcrtiv, imprich, ipeqopt, ipshabt, impsafe, impdiff, ipfrule, ipudrst, ipmodst, ipgdtim, impfree, iphlppl, ipsuces, ipstrgv, ipadvnt, ipbhprp, iprspot, iplylfr, impenv, imptrad, impfun), nfactors=5, rotate="none"))})
#eigenvalues
rowMeans(sapply(famods, function(x) x$e.values))
loads=lapply(famods, loadings)
loadmat=loads[[1]]
for(i in 2:length(loads)){
	loadmat=loadmat + loads[[i]]
}
loadmat=loadmat/length(loads)
loadmat
#so there is a methods factor, and then 2 substantive factors after that
#reestimate with only 3 factors
famods=lapply(implist$imputations, function(x) {with(x, fa(cbind(ipcrtiv, imprich, ipeqopt, ipshabt, impsafe, impdiff, ipfrule, ipudrst, ipmodst, ipgdtim, impfree, iphlppl, ipsuces, ipstrgv, ipadvnt, ipbhprp, iprspot, iplylfr, impenv, imptrad, impfun), nfactors=3, rotate="none"))})
#eigenvalues
rowMeans(sapply(famods, function(x) x$e.values))
loads=lapply(famods, loadings)
loadmat=loads[[1]]
for(i in 2:length(loads)){
	loadmat=loadmat + loads[[i]]
}
loadmat=loadmat/length(loads)
loadmat

#compare factor scores to coding used in paper (but for simplicity in this sensitivity check we are not calculating and standardizing the scores separately in each nation) - endnote 3
fa.cors = lapply(implist$imputations, getcors)
cors=fa.cors[[1]]
for(i in 2:length(fa.cors)){
	cors=cors+fa.cors[[i]]
}
round(cors/length(fa.cors), 3)

# Descriptive Statistics - Online Supplement Part C
#note this gives descriptives on more variables than those used in the paper
nimps=40
data.imps=implist$imputations
exclude.ind=c(1:21, 61:74, 77:166, 177:187)
means=sds=mins=maxes=matrix(nrow=dim(data.imps[[1]][,-exclude.ind])[2], ncol=nimps)
for(i in 1:nimps){
  means[,i]=sapply(data.imps[[i]][,-exclude.ind], wtd.mean, weights=d$wgt)
  sds[,i]=sapply(data.imps[[i]][,-exclude.ind], function(x) sqrt(wtd.var(x, weights=d$wgt)))
  mins[,i]=sapply(data.imps[[i]][,-exclude.ind], min)
  maxes[,i]=sapply(data.imps[[i]][,-exclude.ind], max)
  cat(".")
}
rownames(means)=rownames(sds)=rownames(maxes)=rownames(mins)=colnames(data.imps[[1]][,-exclude.ind])
#pooled
means.mi=rowMeans(means, na.rm=T)
sds.mi=rowMeans(sds, na.rm=T)
mins.mi=rowMeans(mins, na.rm=T)
maxes.mi=rowMeans(maxes, na.rm=T)

desc.mat=cbind(means.mi, sds.mi, mins.mi, maxes.mi)
desc.mat

#Plot Values Circle
#positions pooled across all nations

mi.mat=sapply(implist$imputations, get.mds)  #40 columns, 1st 10 rows are for dim1, 2nd 10 rows for dim2
mi.dim1=rowMeans(mi.mat[1:10,])
mi.dim2=rowMeans(mi.mat[11:20,])

#rotate the plot somewhat for visual presentation
h=ppp(mi.dim1, mi.dim2, window=owin(xrange=c(-28,28), yrange=c(-28,28)))
rotpoints=rotate(h, angle=1.6*pi)
mi.points = cbind(rotpoints$x, rotpoints$y)
#display the plot and add labels, lines, etc.
plot(mi.points, xlim=range(mi.points[,1])+c(-10, 15), ylim=range(mi.points[,2])+c(-20, 15), xlab="Dimension 1", ylab="Dimension 2", pch=19)
text(mi.points, labels=c("Benevolence", "Hedonism", "Tradition", "Conformity", "Stimulation", "Security", "Achievement", "Universalism", "Power", "Self-direction"), pos=1)
abline(a=0, b=-.35)
abline(a=0, b=-7.5)
draw.circle(0,0, radius=max(mi.points)-1)


# Test that covariates are balanced within strata - Table 1
vars.st=c("conserv_z", "female", "age", "ed_upsec", "ed_postsec", "married", "kidshome", "city", "lrscale", "goodpeeps", "trust", "scnsenv", "denom_belong", "bad_exps", "happy", "incomecats", "rlgdgr", "discrim_group", "anydiscuss", "hlth_hamp", "srh")
vars.c=c("self_trans_z", "female", "age", "ed_upsec", "ed_postsec", "married", "kidshome", "city", "lrscale", "goodpeeps", "trust", "scnsenv", "denom_belong", "bad_exps", "happy", "incomecats", "rlgdgr", "discrim_group", "anydiscuss", "hlth_hamp", "srh")
# using MI data, so repeats m=40 times
t.st.mat = sapply(implist$imputations, function(x) check.cor(vars.st, "breaks_selftrans_bynation25peeps", data=x, compare.var="self_trans_z"))
mi.t.st=rowMeans(t.st.mat)
t.c.mat = sapply(implist$imputations, function(x) check.cor(vars.c, "breaks_conserv_bynation25peeps", data=x, compare.var="conserv_z"))
mi.t.c=rowMeans(t.c.mat)
#NOTE: warnings are from strata where there is insufficient variation to calculate a t-test - this suggests perfect balance in that stratum

#output table
nms=unique(c(names(mi.t.st), names(mi.t.c)))
outmat=matrix(NA, nrow=length(nms), ncol=2, dimnames=list(nms, c("st.t", "c.t")))
outmat[match(names(mi.t.st), rownames(outmat)),1]=mi.t.st
outmat[match(names(mi.t.c), rownames(outmat)),2]=mi.t.c
outmat


###########################################################
# ESTIMATE MODELS PREDICTING BEHAVIORS IN ESS
###########################################################

### Calculate effect of values by country 
#Note: a nearly equivalent way to get the estimates by country is to use a model with interactions by each country, but this will differ from a separate model in each country in two ways: 1) the SE's will differ because the variance of the outcome will differ, and hence the scaled covariances will not be equivalent (but the unscaled covariances are equivalent), 2) because the variance of the outcomes differ, standardized coefficients would differ - in the interaction model, you would be standardizing relative to the variance of the outcome across all countries, which is less interpretable than standardizing within countries which you can interpret as "in Austria, a 1 SD increase in x leads to a y SD increase in y"

#religious outcomes
st.attend.cntry=reg.bycntry("attend", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.attend.cntry=reg.bycntry("attend", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

st.pray.cntry=reg.bycntry("pray2", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.pray.cntry=reg.bycntry("pray2", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

#social outcomes
st.meet.cntry=reg.bycntry("meet", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.meet.cntry=reg.bycntry("meet", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

#can't use reg.bycntry function here because of some of the functions don't work right with a clm model (i.e., a function for cumulative logit models), hence I am using the workaround below  
modlist=modlist2=list(); cntry.list=as.character(unique(d$cntry))
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ self_trans_dev25, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "st_strata_mean25", std.coef="y", white.adjust="cluster")
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
st.social.cntry=modlist2

modlist=modlist2=list()
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ cons_dev25, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "c_strata_mean25", std.coef="y", white.adjust="cluster")
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
c.social.cntry=modlist2

st.ever.div.cntry=reg.bycntry("ever_div", "self_trans_dev25", "st_strata_mean25", "logit", std.coef="y")
c.ever.div.cntry=reg.bycntry("ever_div", "cons_dev25", "c_strata_mean25", "logit", std.coef="y")

st.hwork.cntry=reg.bycntry("hwork", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.hwork.cntry=reg.bycntry("hwork", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

st.careothers.hh.cntry=reg.bycntry("careothers_hh", "self_trans_dev25", "st_strata_mean25", "logit", std.coef="y")
c.careothers.hh.cntry=reg.bycntry("careothers_hh", "cons_dev25", "c_strata_mean25", "logit", std.coef="y")

st.careothers.nothh.cntry=reg.bycntry("careothers_nothh", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.careothers.nothh.cntry=reg.bycntry("careothers_nothh", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

st.badacts.cntry=reg.bycntry("badacts", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.badacts.cntry=reg.bycntry("badacts", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")
	
st.voted.cntry=reg.bycntry("voted", "self_trans_dev25", "st_strata_mean25", "logit", std.coef="y")
c.voted.cntry=reg.bycntry("voted", "cons_dev25", "c_strata_mean25", "logit", std.coef="y")			

#NB models cannot be standardized
st.poli.count.cntry=reg.bycntry("poli_count", "self_trans_dev25", "st_strata_mean25", "nb", std.coef="none")
c.poli.count.cntry=reg.bycntry("poli_count", "cons_dev25", "c_strata_mean25", "nb", std.coef="none")

st.tvtime.cntry=reg.bycntry("tvtime", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.tvtime.cntry=reg.bycntry("tvtime", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

st.radiotime.cntry=reg.bycntry("radiotime", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.radiotime.cntry=reg.bycntry("radiotime", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

st.newspap.time.cntry=reg.bycntry("newspap_time", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.newspap.time.cntry=reg.bycntry("newspap_time", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

st.use.www.cntry=reg.bycntry("use_www", "self_trans_dev25", "st_strata_mean25", "lm", std.coef="y")
c.use.www.cntry=reg.bycntry("use_www", "cons_dev25", "c_strata_mean25", "lm", std.coef="y")

##calcualte the value effects - Online Supplement Table E1
mods.list.st=list(st.attend.cntry, st.pray.cntry, st.meet.cntry, st.social.cntry, st.ever.div.cntry, st.hwork.cntry, st.careothers.hh.cntry, st.careothers.nothh.cntry, st.badacts.cntry, st.voted.cntry, st.poli.count.cntry, st.tvtime.cntry, st.radiotime.cntry, st.newspap.time.cntry, st.use.www.cntry)
mods.list.c=list(c.attend.cntry, c.pray.cntry, c.meet.cntry, c.social.cntry, c.ever.div.cntry, c.hwork.cntry, c.careothers.hh.cntry, c.careothers.nothh.cntry, c.badacts.cntry, c.voted.cntry, c.poli.count.cntry, c.tvtime.cntry, c.radiotime.cntry, c.newspap.time.cntry, c.use.www.cntry)

#get p-values for the estimates
st.p=sapply(mods.list.st, function(x) sapply(x, get.p, whichval="self_trans_dev25"))
c.p=sapply(mods.list.c, function(x) sapply(x, get.p, whichval="cons_dev25"))
all.p=matrix(NA, nrow=length(st.attend.cntry), ncol=length(mods.list.st)*2)
all.p[,seq(1,29, by=2)]=st.p
all.p[,seq(2,30, by=2)]=c.p
#get percentage of behaviors in each country predicted by at least 1 value dimension 
tempmat=all.p < .05
newmat=matrix(NA, nrow=nrow(tempmat), ncol=1)
for(i in seq(1,29, by=2)){
	newmat=cbind(newmat, rowMeans(tempmat[,c(i,i+1)]) > 0)
}
newmat=newmat[,-1]
perc.predicted=rowMeans(newmat)
#percentage of nations in which a given behavior is predicted by at least 1 value dimension
num.sig=c()
for(i in seq(1,29, by=2)){
	tempnum=sum(tempmat[,i]==TRUE | tempmat[,i+1]==TRUE)
	num.sig= c(num.sig, rep(tempnum, 2))
}

# put the effects in each country into a table - Table E1
me.mat=matrix(NA, nrow=length(st.attend.cntry), ncol=length(mods.list.st)*2)
me.mat[,seq(1,29, by=2)]=sapply(mods.list.st, function(x) sapply(x, function(y) coef(y)["self_trans_dev25"]))
me.mat[,seq(2,30, by=2)]=sapply(mods.list.c, function(x) sapply(x, function(y) coef(y)["cons_dev25"]))
rownames(me.mat)=cntry.list
varnames=c("attend", "pray", "meet", "social", "ever.div", "hwork", "carehh", "carenothh", "badacts", "voted", "poli.count", "tv", "radio", "newspap", "internet")
colnames(me.mat)[seq(2,30,by=2)]=paste("c", varnames, sep=".")
colnames(me.mat)[seq(1,29,by=2)]=paste("st", varnames, sep=".")
#names the pvalue matrix to match
dimnames(all.p)=dimnames(me.mat)

#add percentages of nations/behaviors predicted for final table
me.mat=cbind(me.mat, perc.predicted)
me.mat=rbind(me.mat, c(num.sig/length(unique(d$cntry)), NA))
me.mat

##to visually see variation in value effects across nations - Figure 2 
behavior.labels=c("service attendance", "prayer", "meet socially", "social activities", "ever divorced", "housework", "care: household", "care: not household", "dishonest acts", "voted", "TV", "radio", "newspaper", "Internet")

#include all columns except activism, which is a count outcome and has no standardized coefficient
whichcols.st=seq(1,29, by=2)
whichcols.st=whichcols.st[-11]
whichcols.c=seq(2,30, by=2)
whichcols.c=whichcols.c[-11]
#I considered only including statistically significant effects, but that throws away the information contained in the non-significant estimates - they could be non-significant because of sampling variability, but might also be non-significant because they represent a non-effect, which is another type of variability (beside positive and negative effects) - instead, I set non-significant effects to 0, essentially assuming that they represent a non-effect
plot.mat = me.mat[-dim(me.mat)[1],-dim(me.mat)[2]]
plot.mat[all.p > .05]=0

par(mfrow=c(2,1))
par(mar=c(7,4,2,2))
boxplot(plot.mat[,whichcols.st], xaxt="n", main="Panel A: Self-transcendence", ylab="standardized coefficient", ylim=c(-.35, .35), range=0, cex.lab=.8)
abline(h=seq(-.3,.3,.1), col="grey")
boxplot(plot.mat[,whichcols.st], xaxt="n", range=0, add=T)
#axis(1, labels=behavior.labels, at=1:14, las=2, cex.axis=.8)
text(1.5:14.5, y=-.42, labels=behavior.labels, srt=45, pos=2, xpd=T, offset=1, cex=.8)

boxplot(plot.mat[,whichcols.c], xaxt="n", main="Panel B: Conservation",  ylab="standardized coefficient", ylim=c(-.35, .35), range=0, cex.lab=.8)
abline(h=seq(-.3,.3,.1), col="grey")
boxplot(plot.mat[,whichcols.c], xaxt="n", range=0, add=T)
#axis(1, labels=behavior.labels, at=1:14, las=2, cex.axis=.8)
text(1.5:14.5, y=-.42, labels=behavior.labels, srt=45, pos=2, xpd=T, offset=1, cex=.8)

#plot proportion of behaviors predicted in each country - Figure 3
dev.off()
bars=na.omit(me.mat[,"perc.predicted"])
cntry.labels=c("Austria", "Belgium", "Switzerland", "Czech Republic", "Germany", "Denmark", "Estonia", "Spain", "Finland", "France", "United Kingdom", "Greece",  "Hungary", "Ireland", "Iceland", "Luxembourg",  "Netherlands", "Norway", "Poland", "Portugal", "Sweden", "Slovenia",   "Slovak Republic", "Turkey", "Ukraine")
barpos=barplot(as.numeric(bars), ylim=c(0,1), xaxt="n", ylab="proportion of behaviors predicted")
abline(h=seq(0,1,.1), col="grey")
barpos=barplot(as.numeric(bars), xaxt="n", add=T)
text(barpos[,1]+1, y=-.02, labels=cntry.labels, srt=45, pos=2, xpd=T, offset=1, cex=.8)
abline(h=mean(bars), lty=2)
text(25, .85, paste("Mean = ", mean(bars)))

#plot proportion of countries in which values predict each behavior - Figure 4
bars=na.omit(me.mat[26,seq(1,29,2)])
behavior.labels2=c("service attendance", "prayer", "meet socially", "social activities", "ever divorced", "housework", "care: household", "care: not household", "dishonest acts", "voted", "activism", "TV", "radio", "newspaper", "Internet")
barpos=barplot(as.numeric(bars), ylim=c(0,1), xaxt="n", ylab="proportion of nations in which values predict")
abline(h=seq(0,1,.1), col="grey")
barpos=barplot(as.numeric(bars), xaxt="n", add=T)
text(barpos[,1]+.5, y=-.02, labels=behavior.labels2, srt=45, pos=2, xpd=T, offset=1, cex=.8)

## what explains the differences in how widely values predict?
#get data with personal freedom index
dat=read.csv("ESS personal freedom.csv")
#add the percent of behaviors values predict in each country
dat=cbind(dat, perc_outcomes=na.omit(me.mat[,"perc.predicted"]))
#drop Luxembourg which does not have a personal freedom score
dat=dat[dat$country!="Luxembourg",]
#indicators for outlier countries
dat$de = ifelse(dat$country=="Germany", 1, 0)
dat$gr = ifelse(dat$country=="Greece", 1, 0)
dat$hu = ifelse(dat$country=="Hungary", 1, 0)

#plot percent of actions predicted by personal freedom index - Figure 5
with(dat, plot(perc_outcomes ~ pfree_score, xlab="personal freedom score", ylab="proportion of behaviors predicted by values"))
labpos = rep(1, dim(dat)[1])
names(labpos)=dat$country
labpos[c("Belgium", "Czech Republic", "Switzerland", "United Kingdom", "Norway", "Hungary")]=3
labpos[c("Netherlands", "Slovenia", "Denmark")]=2
labpos[c("Poland")]=4
with(dat, text(pfree_score, perc_outcomes, labels=country, cex=.7, pos=labpos))
m1=lm(perc_outcomes ~ pfree_score, data=dat)
abline(m1, lty=1)
#test for heteroskedasticity
bptest(m1)  #no need for robust SEs
mod.summary(m1, white.adjust="none")

#adjusting for the three outliers Greece, Germany, and Hungary has very little effect (slope is nearly the same)
m2=lm(perc_outcomes ~ pfree_score + gr + de + hu, data=dat)
abline(a=coef(m2)[1], b=coef(m2)[2], lty=2)

## varying the size of the strata - Figure 6

#restimate models with various strata sizes
#30 per stratum
st.attend.cntry30=reg.bycntry("attend", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.attend.cntry30=reg.bycntry("attend", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.pray.cntry30=reg.bycntry("pray2", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.pray.cntry30=reg.bycntry("pray2", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.meet.cntry30=reg.bycntry("meet", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.meet.cntry30=reg.bycntry("meet", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
modlist=modlist2=list(); cntry.list=as.character(unique(d$cntry))
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ self_trans_dev30, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "st_strata_mean30", std.coef="y", white.adjust="cluster")
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
st.social.cntry30=modlist2
modlist=modlist2=list()
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ cons_dev30, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "c_strata_mean30", std.coef="y", white.adjust="cluster")
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
c.social.cntry30=modlist2
st.ever.div.cntry30=reg.bycntry("ever_div", "self_trans_dev30", "st_strata_mean30", "logit", std.coef="y")
c.ever.div.cntry30=reg.bycntry("ever_div", "cons_dev30", "c_strata_mean30", "logit", std.coef="y")
st.hwork.cntry30=reg.bycntry("hwork", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.hwork.cntry30=reg.bycntry("hwork", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.careothers.hh.cntry30=reg.bycntry("careothers_hh", "self_trans_dev30", "st_strata_mean30", "logit", std.coef="y")
c.careothers.hh.cntry30=reg.bycntry("careothers_hh", "cons_dev30", "c_strata_mean30", "logit", std.coef="y")
st.careothers.nothh.cntry30=reg.bycntry("careothers_nothh", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.careothers.nothh.cntry30=reg.bycntry("careothers_nothh", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.badacts.cntry30=reg.bycntry("badacts", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.badacts.cntry30=reg.bycntry("badacts", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.voted.cntry30=reg.bycntry("voted", "self_trans_dev30", "st_strata_mean30", "logit", std.coef="y")
c.voted.cntry30=reg.bycntry("voted", "cons_dev30", "c_strata_mean30", "logit", std.coef="y")			
#NB models cannot be standardized
st.poli.count.cntry30=reg.bycntry("poli_count", "self_trans_dev30", "st_strata_mean30", "nb", std.coef="none")
c.poli.count.cntry30=reg.bycntry("poli_count", "cons_dev30", "c_strata_mean30", "nb", std.coef="none")
st.tvtime.cntry30=reg.bycntry("tvtime", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.tvtime.cntry30=reg.bycntry("tvtime", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.radiotime.cntry30=reg.bycntry("radiotime", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.radiotime.cntry30=reg.bycntry("radiotime", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.newspap.time.cntry30=reg.bycntry("newspap_time", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.newspap.time.cntry30=reg.bycntry("newspap_time", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")
st.use.www.cntry30=reg.bycntry("use_www", "self_trans_dev30", "st_strata_mean30", "lm", std.coef="y")
c.use.www.cntry30=reg.bycntry("use_www", "cons_dev30", "c_strata_mean30", "lm", std.coef="y")

#20 per stratum
st.attend.cntry20=reg.bycntry("attend", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.attend.cntry20=reg.bycntry("attend", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.pray.cntry20=reg.bycntry("pray2", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.pray.cntry20=reg.bycntry("pray2", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.meet.cntry20=reg.bycntry("meet", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.meet.cntry20=reg.bycntry("meet", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
modlist=modlist2=list(); cntry.list=as.character(unique(d$cntry))
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ self_trans_dev20, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "st_strata_mean20", std.coef="y", white.adjust="cluster")
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
st.social.cntry20=modlist2
modlist=modlist2=list()
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ cons_dev20, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "c_strata_mean20", std.coef="y", white.adjust='cluster')
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
c.social.cntry20=modlist2
st.ever.div.cntry20=reg.bycntry("ever_div", "self_trans_dev20", "st_strata_mean20", "logit", std.coef="y")
c.ever.div.cntry20=reg.bycntry("ever_div", "cons_dev20", "c_strata_mean20", "logit", std.coef="y")
st.hwork.cntry20=reg.bycntry("hwork", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.hwork.cntry20=reg.bycntry("hwork", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.careothers.hh.cntry20=reg.bycntry("careothers_hh", "self_trans_dev20", "st_strata_mean20", "logit", std.coef="y")
c.careothers.hh.cntry20=reg.bycntry("careothers_hh", "cons_dev20", "c_strata_mean20", "logit", std.coef="y")
st.careothers.nothh.cntry20=reg.bycntry("careothers_nothh", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.careothers.nothh.cntry20=reg.bycntry("careothers_nothh", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.badacts.cntry20=reg.bycntry("badacts", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.badacts.cntry20=reg.bycntry("badacts", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.voted.cntry20=reg.bycntry("voted", "self_trans_dev20", "st_strata_mean20", "logit", std.coef="y")
c.voted.cntry20=reg.bycntry("voted", "cons_dev20", "c_strata_mean20", "logit", std.coef="y")			
#NB models cannot be standardized
st.poli.count.cntry20=reg.bycntry("poli_count", "self_trans_dev20", "st_strata_mean20", "nb", std.coef="none")
c.poli.count.cntry20=reg.bycntry("poli_count", "cons_dev20", "c_strata_mean20", "nb", std.coef="none")
st.tvtime.cntry20=reg.bycntry("tvtime", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.tvtime.cntry20=reg.bycntry("tvtime", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.radiotime.cntry20=reg.bycntry("radiotime", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.radiotime.cntry20=reg.bycntry("radiotime", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.newspap.time.cntry20=reg.bycntry("newspap_time", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.newspap.time.cntry20=reg.bycntry("newspap_time", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")
st.use.www.cntry20=reg.bycntry("use_www", "self_trans_dev20", "st_strata_mean20", "lm", std.coef="y")
c.use.www.cntry20=reg.bycntry("use_www", "cons_dev20", "c_strata_mean20", "lm", std.coef="y")

#no adjustment - don't need to change the cluster variable since that doesn't effect the standardized coefficient, but I'll turn off clustered SE's to make the function run a bit faster)
st.attend.none=reg.bycntry("attend", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.attend.none=reg.bycntry("attend", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.pray.none=reg.bycntry("pray2", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.pray.none=reg.bycntry("pray2", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.meet.none=reg.bycntry("meet", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.meet.none=reg.bycntry("meet", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
modlist=modlist2=list(); cntry.list=as.character(unique(d$cntry))
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ self_trans_z, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "st_strata_mean20", std.coef="y", white.adjust="none")
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
st.social.none=modlist2
modlist=modlist2=list()
for(j in 1:length(cntry.list)){
	cat("\n", cntry.list[[j]])
	for(i in 1:length(implist$imputations)){
		modlist[[i]]=clm(social.fac ~ conserv_z, weight=wgt, subset=!d$miss_social & cntry==cntry.list[[j]], data=implist$imputations[[i]])
	} #end i loop
	modlist=modify.model(modlist, "c_strata_mean20", std.coef="y", white.adjust="none")
	modlist2[[j]]=MIcombine(lapply(modlist, function(x) {coef(x)[,1]}), lapply(modlist, function(x) coef(x)[,2]^2))
} #end j loop
c.social.none=modlist2
st.ever.div.none=reg.bycntry("ever_div", "self_trans_z", "st_strata_mean20", "logit", std.coef="y", white.adjust="none")
c.ever.div.none=reg.bycntry("ever_div", "conserv_z", "c_strata_mean20", "logit", std.coef="y", white.adjust="none")
st.hwork.none=reg.bycntry("hwork", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.hwork.none=reg.bycntry("hwork", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.careothers.hh.none=reg.bycntry("careothers_hh", "self_trans_z", "st_strata_mean20", "logit", std.coef="y", white.adjust="none")
c.careothers.hh.none=reg.bycntry("careothers_hh", "conserv_z", "c_strata_mean20", "logit", std.coef="y", white.adjust="none")
st.careothers.nothh.none=reg.bycntry("careothers_nothh", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.careothers.nothh.none=reg.bycntry("careothers_nothh", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.badacts.none=reg.bycntry("badacts", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.badacts.none=reg.bycntry("badacts", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.voted.none=reg.bycntry("voted", "self_trans_z", "st_strata_mean20", "logit", std.coef="y", white.adjust="none")
c.voted.none=reg.bycntry("voted", "conserv_z", "c_strata_mean20", "logit", std.coef="y", white.adjust="none")			
#NB models cannot be standardized
st.poli.count.none=reg.bycntry("poli_count", "self_trans_z", "st_strata_mean20", "nb", std.coef="none", white.adjust="none")
c.poli.count.none=reg.bycntry("poli_count", "conserv_z", "c_strata_mean20", "nb", std.coef="none", white.adjust="none")
st.tvtime.none=reg.bycntry("tvtime", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.tvtime.none=reg.bycntry("tvtime", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.radiotime.none=reg.bycntry("radiotime", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.radiotime.none=reg.bycntry("radiotime", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.newspap.time.none=reg.bycntry("newspap_time", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.newspap.time.none=reg.bycntry("newspap_time", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")
st.use.www.none=reg.bycntry("use_www", "self_trans_z", "st_strata_mean20", "lm", std.coef="y", white.adjust="none")
c.use.www.none=reg.bycntry("use_www", "conserv_z", "c_strata_mean20", "lm", std.coef="y", white.adjust="none")

##generate a series of plots showing the change in coefficient as you change the number of people in each stratum - Figure 6

#self-transendence
mods.list.st=list(st.attend.cntry, st.pray.cntry, st.meet.cntry, st.social.cntry, st.ever.div.cntry, st.hwork.cntry, st.careothers.hh.cntry, st.careothers.nothh.cntry, st.badacts.cntry, st.voted.cntry, st.poli.count.cntry, st.tvtime.cntry, st.radiotime.cntry, st.newspap.time.cntry, st.use.www.cntry)
mods.list.st30=list(st.attend.cntry30, st.pray.cntry30, st.meet.cntry30, st.social.cntry30, st.ever.div.cntry30, st.hwork.cntry30, st.careothers.hh.cntry30, st.careothers.nothh.cntry30, st.badacts.cntry30, st.voted.cntry30, st.poli.count.cntry30, st.tvtime.cntry30, st.radiotime.cntry30, st.newspap.time.cntry30, st.use.www.cntry30)
mods.list.st20=list(st.attend.cntry20, st.pray.cntry20, st.meet.cntry20, st.social.cntry20, st.ever.div.cntry20, st.hwork.cntry20, st.careothers.hh.cntry20, st.careothers.nothh.cntry20, st.badacts.cntry20, st.voted.cntry20, st.poli.count.cntry20, st.tvtime.cntry20, st.radiotime.cntry20, st.newspap.time.cntry20, st.use.www.cntry20)
mods.list.st.none=list(st.attend.none, st.pray.none, st.meet.none, st.social.none, st.ever.div.none, st.hwork.none, st.careothers.hh.none, st.careothers.nothh.none, st.badacts.none, st.voted.none, st.poli.count.none, st.tvtime.none, st.radiotime.none, st.newspap.time.none, st.use.www.none)

st.30=sapply(mods.list.st30, function(x) sapply(x, function(y) coef(y)["self_trans_dev30"]))
st.25=sapply(mods.list.st, function(x) sapply(x, function(y) coef(y)["self_trans_dev25"]))
st.20=sapply(mods.list.st20, function(x) sapply(x, function(y) coef(y)["self_trans_dev20"]))
st.none=sapply(mods.list.st.none, function(x) sapply(x, function(y) coef(y)["self_trans_z"]))

varmat=matrix(NA, nrow=nrow(st.25), ncol=ncol(st.25))
for(i in 1:nrow(varmat)){
	for(j in 1:ncol(varmat)){
		varmat[i,j]=var(c(st.30[i,j], st.25[i,j], st.20[i,j]))
	}
}
#which country has the highest mean level of variation - i.e. in which country does changing the strata make the most difference on average?
var.bycntry=apply(varmat, 1, mean)
names(var.bycntry)=unique(d$cntry)
var.bycntry[var.bycntry==max(var.bycntry)]

index.st=which(var.bycntry==max(var.bycntry))

#conservation
mods.list.c=list(c.attend.cntry, c.pray.cntry, c.meet.cntry, c.social.cntry, c.ever.div.cntry, c.hwork.cntry, c.careothers.hh.cntry, c.careothers.nothh.cntry, c.badacts.cntry, c.voted.cntry, c.poli.count.cntry, c.tvtime.cntry, c.radiotime.cntry, c.newspap.time.cntry, c.use.www.cntry)
mods.list.c30=list(c.attend.cntry30, c.pray.cntry30, c.meet.cntry30, c.social.cntry30, c.ever.div.cntry30, c.hwork.cntry30, c.careothers.hh.cntry30, c.careothers.nothh.cntry30, c.badacts.cntry30, c.voted.cntry30, c.poli.count.cntry30, c.tvtime.cntry30, c.radiotime.cntry30, c.newspap.time.cntry30, c.use.www.cntry30)
mods.list.c20=list(c.attend.cntry20, c.pray.cntry20, c.meet.cntry20, c.social.cntry20, c.ever.div.cntry20, c.hwork.cntry20, c.careothers.hh.cntry20, c.careothers.nothh.cntry20, c.badacts.cntry20, c.voted.cntry20, c.poli.count.cntry20, c.tvtime.cntry20, c.radiotime.cntry20, c.newspap.time.cntry20, c.use.www.cntry20)
mods.list.c.none=list(c.attend.none, c.pray.none, c.meet.none, c.social.none, c.ever.div.none, c.hwork.none, c.careothers.hh.none, c.careothers.nothh.none, c.badacts.none, c.voted.none, c.poli.count.none, c.tvtime.none, c.radiotime.none, c.newspap.time.none, c.use.www.none)

c.30=sapply(mods.list.c30, function(x) sapply(x, function(y) coef(y)["cons_dev30"]))
c.25=sapply(mods.list.c, function(x) sapply(x, function(y) coef(y)["cons_dev25"]))
c.20=sapply(mods.list.c20, function(x) sapply(x, function(y) coef(y)["cons_dev20"]))
c.none=sapply(mods.list.c.none, function(x) sapply(x, function(y) coef(y)["conserv_z"]))

varmat=matrix(NA, nrow=nrow(c.25), ncol=ncol(c.25))
for(i in 1:nrow(varmat)){
	for(j in 1:ncol(varmat)){
		varmat[i,j]=var(c(c.30[i,j], c.25[i,j], c.20[i,j]))
	}
}

#which country has the highest mean level of variation - i.e. in which country does changing the strata make the most difference on average?
var.bycntry=apply(varmat, 1, mean)
names(var.bycntry)=unique(d$cntry)
var.bycntry[var.bycntry==max(var.bycntry)]  
index.c=which(var.bycntry==max(var.bycntry))

behavior.labels=c("service attendance", "prayer", "meet socially", "social activities", "ever divorced", "housework", "care: household", "care: not household", "dishonest acts", "voted", "activism", "TV", "radio", "newspaper", "Internet")
barcolors=c("grey10", "grey30", "grey50", "grey90")

#Figure 6
par(mfrow=c(2,1))
par(mar=c(7,4,2,2))
bars=barplot(rbind(abs(st.none[index.st,]), abs(st.30[index.st,]), abs(st.25[index.st,]), abs(st.20[index.st,])), beside=T, names.arg=behavior.labels, las=2, xaxt="n", main="Self-transcendence (most variable nation)", col=barcolors, ylab="effect size")
text(bars[4,], y=-.01, labels=behavior.labels, srt=45, pos=2, xpd=T, offset=1, cex=.8)
legend("topleft", inset=.01, title="strata size", legend=c("none",30,25,20), fill=barcolors, cex=.8)

bars=barplot(rbind(abs(c.none[index.c,]), abs(c.30[index.c,]), abs(c.25[index.c,]), abs(c.20[index.c,])), beside=T, names.arg=behavior.labels, las=2, xaxt="n", main="Conservation (most variable nation)", col=barcolors, ylab="effect size")
text(bars[4,], y=-.01, labels=behavior.labels, srt=45, pos=2, xpd=T, offset=1, cex=.8)


### comparison to control variables - Online Supplement Table F1

#no need for clustered SEs since no variables are mean-deviated

attend.cntrl = cntrl.bycntry("attend", "lm", std.coef="mix")
pray.cntrl = cntrl.bycntry("pray2", "lm", std.coef="mix")
meet.cntrl = cntrl.bycntry("meet", "lm", std.coef="mix")
social.cntrl=cntrl.bycntry("social.fac", "ologit", std.coef="mix")
ever.div.cntrl = cntrl.bycntry("ever_div", "logit", std.coef="mix")
hwork.cntrl = cntrl.bycntry("hwork", "lm", std.coef="mix")
careothers.hh.cntrl = cntrl.bycntry("careothers_hh", "logit", std.coef="mix")
careothers.nothh.cntrl = cntrl.bycntry("careothers_nothh", "lm", std.coef="mix")
badacts.cntrl = cntrl.bycntry("badacts", "lm", std.coef="mix")
voted.cntrl = cntrl.bycntry("voted", "logit", std.coef="mix")
poli.count.cntrl = cntrl.bycntry("poli_count", "nb", std.coef="none")
tvtime.cntrl = cntrl.bycntry("tvtime", "lm", std.coef="mix")
radiotime.cntrl = cntrl.bycntry("radiotime", "lm", std.coef="mix")		
newspap.time.cntrl = cntrl.bycntry("newspap_time", "lm", std.coef="mix")
use.www.cntrl = cntrl.bycntry("use_www", "lm", std.coef="mix")

#isolate the statistically significant effects and take their absolute value
attend.cntrl2=lapply(attend.cntrl, sig.cfs)
pray.cntrl2 = lapply(pray.cntrl, sig.cfs)
meet.cntrl2 = lapply(meet.cntrl, sig.cfs)
social.cntrl2=lapply(social.cntrl, sig.cfs)
ever.div.cntrl2 = lapply(ever.div.cntrl, sig.cfs)
hwork.cntrl2 = lapply(hwork.cntrl, sig.cfs)
careothers.hh.cntrl2 = lapply(careothers.hh.cntrl, sig.cfs)
careothers.nothh.cntrl2 = lapply(careothers.nothh.cntrl, sig.cfs)
badacts.cntrl2 = lapply(badacts.cntrl, sig.cfs)
voted.cntrl2 = lapply(voted.cntrl, sig.cfs)
poli.count.cntrl2 = lapply(poli.count.cntrl, sig.cfs)
tvtime.cntrl2 = lapply(tvtime.cntrl, sig.cfs)
radiotime.cntrl2 = lapply(radiotime.cntrl, sig.cfs)		
newspap.time.cntrl2 = lapply(newspap.time.cntrl, sig.cfs)
use.www.cntrl2 = lapply(use.www.cntrl, sig.cfs)

#average the coefficients across nations
attend.coefs=rowMeans(do.call(cbind, attend.cntrl2), na.rm=T)
pray.coefs=rowMeans(do.call(cbind, pray.cntrl2), na.rm=T)
meet.coefs=rowMeans(do.call(cbind, meet.cntrl2), na.rm=T)
social.coefs=rowMeans(do.call(cbind, social.cntrl2), na.rm=T)
ever.div.coefs=rowMeans(do.call(cbind, ever.div.cntrl2), na.rm=T)
hwork.coefs=rowMeans(do.call(cbind, hwork.cntrl2), na.rm=T)
careothers.hh.coefs=rowMeans(do.call(cbind, careothers.hh.cntrl2), na.rm=T)
careothers.nothh.coefs=rowMeans(do.call(cbind, careothers.nothh.cntrl2), na.rm=T)
badacts.coefs=rowMeans(do.call(cbind, badacts.cntrl2), na.rm=T)
voted.coefs=rowMeans(do.call(cbind, voted.cntrl2), na.rm=T)
poli.count.coefs=rowMeans(do.call(cbind, poli.count.cntrl2), na.rm=T)
tvtime.coefs=rowMeans(do.call(cbind, tvtime.cntrl2), na.rm=T)
radiotime.coefs=rowMeans(do.call(cbind, radiotime.cntrl2), na.rm=T)
newspap.time.coefs=rowMeans(do.call(cbind, newspap.time.cntrl2), na.rm=T)
use.www.coefs=rowMeans(do.call(cbind, use.www.cntrl2), na.rm=T)

#since there is more than one intercept in one of the models, trim off intercepts before combining 
social.coefs=social.coefs[-c(1:3)]
cntrlmat=cbind(attend.coefs, pray.coefs, meet.coefs, social.coefs, ever.div.coefs, hwork.coefs, careothers.hh.coefs, careothers.nothh.coefs, badacts.coefs, voted.coefs, poli.count.coefs, tvtime.coefs, radiotime.coefs, newspap.time.coefs, use.www.coefs)

#now get the average of statistically significant value effects for each outcome
valmat=me.mat[-nrow(me.mat), -ncol(me.mat)]
valmat[all.p > .05]=NA
valeffects=colMeans(abs(valmat), na.rm=T)
valeffects=matrix(valeffects, nrow=2)
rownames(valeffects)=c("st","c")

compare.mat=rbind(valeffects, cntrlmat[-1,])
compare.mat








