#### Analysis file for replicating analyses from Miles, Andrew. 2015. "The (Re)genesis of Values: Examining the Importance of Values for Action." American Sociological Review ??(??):??

#### This file is designed to read in round 2 ESS data, code it, and impute it
#ESS data, round 2, can be downloaded from http://www.europeansocialsurvey.org/download.html?file=ESS2e03_4&y=2004
#NOTE: the version of the data file that I used is the SPSS format, file ESS2e03_3.sav - current data files might differ slightly
#if you download the SAS or STATA versions, you will need to use different commands to import the data, e.g., read.dta() instead of read.spss()

#load required packages
library(foreign); library(multilevel); library(MASS); library(Amelia); library(mitools)

#read in ESS data with contextual variables - wave 2, note the warning seems to have no practical consequence and can be ignored, hence I'm using suppressWarnings()
#d=suppressWarnings(read.spss(file="YOUR ESS DATA FILE IN SPSS FORMAT HERE", to.data.frame=T, use.value.labels=F))
d=suppressWarnings(read.spss(file="ESS2e03_3.sav", to.data.frame=T, use.value.labels=F))
#read in country-specific files with extra data to fill in data that is missing in the overall file
# d.ee=read.spss(file="YOUR ESS EE DATA FILE HERE", to.data.frame=T, use.value.labels=F)
# d.ua=read.spss(file="YOUR ESS UA DATA FILE HERE", to.data.frame=T, use.value.labels=F)
# d.fi=read.spss(file="YOUR ESS FI DATA FILE HERE", to.data.frame=T, use.value.labels=F)
# d.fr=read.spss(file="YOUR ESS FR DATA FILE HERE", to.data.frame=T, use.value.labels=F)
d.ee=read.spss(file="ESS2csEE.por", to.data.frame=T, use.value.labels=F)
d.ua=read.spss(file="ESS2csUA.por", to.data.frame=T, use.value.labels=F)
d.fi=read.spss(file="ESS2csFI.por", to.data.frame=T, use.value.labels=F)
d.fr=read.spss(file="ESS2csFR.por", to.data.frame=T, use.value.labels=F)

#code missing for needed variables in the country-specific files
d.ua$HINCTUA = ifelse(d.ua$HINCTUA > 12, NA, d.ua$HINCTUA)
d.ee$HINCTEE = ifelse(d.ee$HINCTEE > 12, NA, d.ee$HINCTEE)
d.fr$NETUSE1 = ifelse(d.fr$NETUSE1 > 7, NA, d.fr$NETUSE1)
d.fr$NETUSE2 = ifelse(d.fr$NETUSE2 > 7, NA, d.fr$NETUSE2)
# combine the two FR netuse variables into 1
d.fr$netuseFR = with(d.fr, rowMeans(cbind(NETUSE1, NETUSE2)))

#merge income data for country-specific files into main file
d.ua$idno = d.ua$IDNO
d.ua$cntry = d.ua$CNTRY
d.ee$idno = d.ee$IDNO
d.ee$cntry = d.ee$CNTRY
d.fi$idno = d.fi$IDNO
d.fi$cntry = d.fi$CNTRY
d.fr$idno = d.fr$IDNO
d.fr$cntry = d.fr$CNTRY
d.ua$IDNO = d.ua$CNTRY = d.ee$IDNO = d.ee$CNTRY = d.fi$IDNO = d.fi$CNTRY = d.fr$IDNO = d.fr$CNTRY = NULL
#trim off a few more unwanted columns
d.fi = d.fi[,c("idno", "cntry", "RLGBLGFI")]
d.fr = d.fr[,c("idno", "cntry", "netuseFR")]

d=merge(d, d.ua, all.x=T, by=c("cntry", "idno"))
d=merge(d, d.ee, all.x=T, by=c("cntry", "idno"))
d=merge(d, d.fi, all.x=T, by=c("cntry", "idno"))
d=merge(d, d.fr, all.x=T, by=c("cntry", "idno"))

#add income information from EE and UA to main income variable
d$hinctnt = ifelse(d$cntry=="EE", d$HINCTEE, d$hinctnt)
d$hinctnt = ifelse(d$cntry=="UA", d$HINCTUA, d$hinctnt)
#add denominational belonging info from FI to main denomination variable
d$rlgblg = ifelse(d$cntry=="FI", d$RLGBLGFI, d$rlgblg)
#add internet use informaton from FR to main internet variable
d$netuse = ifelse(d$cntry=="FR", d$netuseFR, d$netuse)

##code behavioral variables 

#religious behaviors
d$attend = 8-d$rlgatnd
d$pray2 = 8-d$pray

#social behaviors
d$social = d$sclact
d$meet = d$sclmeet

#family-related behaviors
d$hwork_weekday = ifelse(d$icptn==1, d$hwkpwd1, d$hwkpwd2)
d$hwork_weekend = ifelse(d$icptn==1, d$hwkpwe1, d$hwkpwe2)
with(d, cor(hwork_weekday, hwork_weekend, use="pair"))  #patterns of housework similar on weekdays and weekends
d$hwork = with(d, rowMeans(cbind(hwork_weekday, hwork_weekend), na.rm=T))
d$ever_div = ifelse(d$dvrcdev==1, 1, 0)

#prosocial behaviors
d$careothers_hh = ifelse(d$lkafohh==1, 1, 0)
d$careothers_nothh = d$updhlrl
d$keptchange = d$kptchng
d$avoidtax = d$payavtx
d$soldbad = d$slcnsfl
d$alterdoc = d$musdocm
d$falseins = d$flinsr
d$bribe = d$pbofvr
d$falseclaim = d$flgvbnf
with(d, cronbach(cbind(keptchange, avoidtax, soldbad, alterdoc, falseins, bribe, falseclaim))) #different dishonest behaviors seem to form a coherent scale
d$badacts = with(d, rowMeans(cbind(keptchange, avoidtax, soldbad, alterdoc, falseins, bribe, falseclaim), na.rm=T))

#political behaviors
d$voted = ifelse(d$vote==3, NA, ifelse(d$vote==1, 1, 0))
d$contact_polit = ifelse(d$contplt==1, 1, 0)
d$workparty = ifelse(d$wrkprty==1, 1, 0)
d$workorg = ifelse(d$wrkorg==1, 1, 0)
d$worn_badge = ifelse(d$badge==1, 1, 0)
d$petition = ifelse(d$sgnptit==1, 1, 0)
d$demonstrate = ifelse(d$pbldmn==1, 1, 0)
d$boycott = ifelse(d$bctprd==1, 1, 0)
d$poli_count = with(d, rowSums(cbind(contact_polit, workparty, workorg, worn_badge, petition, demonstrate, boycott)))

#time-use behaviors
d$tvtime = d$tvtot
d$tv_politics = d$tvpol
d$radiotime = d$rdtot
d$radio_politics = d$rdpol
d$newspap_time = d$nwsptot
d$newspap_politics = d$nwsppol
d$use_www = d$netuse
#code as missing any who don't have access to the internet
d$use_www = ifelse(d$use_www==0, NA, d$use_www)

#weight that combines design weight and population size weight
d$wgt=d$dweight*d$pweight

#code Schwartz values
#recode so higher is higher on the value
d$ipcrtiv = 7- d$ipcrtiv
d$imprich = 7- d$imprich
d$ipeqopt = 7- d$ipeqopt
d$ipshabt = 7- d$ipshabt
d$impsafe = 7- d$impsafe
d$impdiff = 7- d$impdiff
d$ipfrule = 7- d$ipfrule
d$ipudrst = 7- d$ipudrst
d$ipmodst = 7- d$ipmodst
d$ipgdtim = 7- d$ipgdtim
d$impfree = 7- d$impfree
d$iphlppl = 7- d$iphlppl
d$ipsuces = 7- d$ipsuces
d$ipstrgv = 7- d$ipstrgv
d$ipadvnt = 7- d$ipadvnt
d$ipbhprp = 7- d$ipbhprp
d$iprspot = 7- d$iprspot
d$iplylfr = 7- d$iplylfr
d$impenv = 7- d$impenv
d$imptrad = 7- d$imptrad
d$impfun = 7- d$impfun

#demographics/controls 
d$married = ifelse(d$marital==1, 1, 0)
#add in marriage data from France
d$married = ifelse(d$cntry=="FR", ifelse(d$martlfr==1, 1, 0), d$married)
d$denom_belong = ifelse(d$rlgblg==1, 1, 0)
d$discrim_group = ifelse(d$dscrgrp==1, 1, 0)
#a correction for a coding error in SI - see ESS codebook
d$discrim_group = ifelse(is.na(d$discrim_group) & d$dscrref==1 & d$cntry=="SI", 0, d$discrim_group)
d$paidjob_ever = ifelse(d$crpdwk==1 | d$pdjobev==1, 1, 0)
d$female=ifelse(d$gndr==2, 1, 0)
d$age=d$agea
d$kidshome=ifelse(d$chldhm==1, 1, 0)
d$city = ifelse(d$domicil==1 | d$domicil==2, 1, 0)
d$educ = ifelse(d$eisced==55, NA, d$eisced)
#a different education variable, with fewer missing - replace the one I have which is based on EISCED, with the one based on EDULVLA
d$educ_v2 = ifelse(d$edulvla>=55, NA, d$edulvla)
d$ed_upsec = ifelse(d$educ_v2 == 3, 1, 0)
d$ed_postsec = ifelse(d$educ_v2 > 3, 1, 0)
d$anydiscuss = ifelse(d$inmdisc==1, 1, 0)
d$srh = 6-d$health
d$hlth_hamp = 4-d$hlthhmp
d$bad_exps = with(d, rowMeans(cbind(rprochg, fodcncl, bnkfldl, scndhfl, pboafvr), na.rm=T))
d$incomecats = d$hinctnt

#can I compress some items into scales?
with(d, cor(cbind(trstprl, trstlgl, trstplc, trstplt, trstprt, trstep, trstun), use="pair"))
with(d, cor(cbind(imdfetn, impcntr, imbgeco, imueclt, imwbcnt), use="pair"))
with(d, cronbach(cbind(trstprl, trstlgl, trstplc, trstplt, trstprt, trstep, trstun)))
#other variables tstrprh, tstfnch, tstpboh don't improve the scale, but don't hurt it much either, so I'll leave them out confident that they are just more ways of tapping generalized trust
with(d, cronbach(cbind(imdfetn, impcntr, 11-imbgeco, 11-imueclt, 11-imwbcnt)))
#so these can be used to form scales
d$trust = with(d, rowMeans(cbind(trstprl, trstlgl, trstplc, trstplt, trstprt, trstep, trstun)), na.rm=T)
d$immig_att = with(d, rowMeans(cbind(imdfetn, impcntr, 11-imbgeco, 11-imueclt, 11-imwbcnt)), na.rm=T)
d$goodpeeps = with(d, rowMeans(cbind(ppltrst, pplfair, pplhlp), na.rm=T))

#generate indicator for which cases are originally missing on each outcome variable so that I can exclude them from analyses- see von Hippel 2007
d$miss_attend=is.na(d$attend)
d$miss_pray2=is.na(d$pray2)
d$miss_social=is.na(d$social)
d$miss_meet=is.na(d$meet)
d$miss_ever_div=is.na(d$ever_div)
d$miss_hwork=is.na(d$hwork)
d$miss_careothers_hh=is.na(d$careothers_hh)
d$miss_careothers_nothh=is.na(d$careothers_nothh)
d$miss_badacts=is.na(d$badacts)
d$miss_voted=is.na(d$voted)
d$miss_poli_count=is.na(d$poli_count)
d$miss_tvtime=is.na(d$tvtime)
d$miss_radiotime=is.na(d$radiotime)
d$miss_newspap_time=is.na(d$newspap_time)
d$miss_use_www=is.na(d$use_www)

#a simple identification variable
d$idvar=seq(from=1, to=dim(d)[1])

#remove unneccessary objects from workspace
rm(d.ee, d.fi, d.fr, d.ua)

###### IMPUTATIONS ######

#NOTE: there are a number of data checks that I performed that I have included but commented out to help the code run faster and the output be less confusing

#there are two types of variables to include in the imputation model - ones that you think matter substantively (they are in the analysis), and ones that you think help make the missingness ignorable

##which variables predict missingness?
#missingness indicators
d$self_trans = with(d, rowMeans(cbind(iphlppl, iplylfr, ipeqopt, ipudrst, impenv, -imprich, -iprspot, -ipshabt, -ipsuces)))
d$conserv = with(d, rowMeans(cbind(-ipgdtim, -impfun, -impdiff, -ipadvnt, -ipcrtiv, -impfree, impsafe, ipstrgv, ipfrule, ipbhprp, ipmodst, imptrad)))
d$miss_st = ifelse(is.na(d$self_trans), 1, 0)
d$miss_c = ifelse(is.na(d$conserv), 1, 0)

#additional variables that might predict missingess
d$immigrant = ifelse(is.na(d$livecntr), 0, 1)
d$minority = ifelse(d$blgetmg==1, 1, 0)
d$unemp_disable = ifelse(d$uempla==1 | d$uempli==1 | d$dsbld==1, 1, 0)

#since the imputation model makes a joint normality assumption, test what predicts missingness using a rough linear probability model
test=d[,c("female", "age", "educ", "married", "kidshome", "city", "lrscale", "goodpeeps", "trust", "rlgdgr", "discrim_group", "hwork", "careothers_hh", "careothers_nothh", "happy", "srh", "hlth_hamp", "incomecats", "wgt", "aesfdrk", "pdwrk", "immigrant", "minority", "unemp_disable", "rtrd", "hswrk", "inwtm", "miss_st", "miss_c")]
test=na.omit(test)
missmod.st=lm(miss_st ~ female + age + educ + married + kidshome + city + lrscale + goodpeeps + trust + rlgdgr + discrim_group + hwork + careothers_hh + careothers_nothh + happy + srh + hlth_hamp + incomecats + wgt + aesfdrk + pdwrk + immigrant + minority + unemp_disable + rtrd + hswrk + inwtm, data=test)
missmod.st=stepAIC(missmod.st, direction="both", trace=0)
summary(missmod.st)
missmod.c=lm(miss_c ~ female + age + educ + married + kidshome + city + lrscale + goodpeeps + trust + rlgdgr + discrim_group + hwork + careothers_hh + careothers_nothh + happy + srh + hlth_hamp + incomecats + wgt + aesfdrk + pdwrk + immigrant + minority + unemp_disable + rtrd + hswrk + inwtm, data=test)
missmod.c=stepAIC(missmod.c, direction="both", trace=0)
summary(missmod.c)

#the set of variables to impute 
#impute the individual value items - the scales with the mean subtracted are exactly dependent
impvars=with(d, data.frame(ipcrtiv, imprich, ipeqopt, ipshabt, impsafe, impdiff, ipfrule, ipudrst, ipmodst, ipgdtim, impfree, iphlppl, ipsuces, ipstrgv, ipadvnt, ipbhprp, iprspot, iplylfr, impenv, imptrad, impfun, female, age, married, kidshome, city, lrscale, goodpeeps, trust, tvtime, radiotime, newspap_time, use_www, scnsenv, denom_belong, rlgdgr, discrim_group, ever_div, attend, pray2, social, meet, voted, poli_count, badacts, hwork, careothers_hh, careothers_nothh, happy, anydiscuss, srh, hlth_hamp, bad_exps, incomecats, aesfdrk, pdwrk, minority, rtrd, ed_upsec, ed_postsec, wgt, idvar, cntry))
#a few indicators to mark variables that will not be imputed
idvars=c("idvar", "cntry")
idvars.nowgt =c("idvar", "cntry", "wgt")

# #data check - do I want to transform any variables to improve normality?
# attach(d)
# par(mfrow=c(2,2))
# hist(impfun); hist(sv_selfd); hist(sv_power); hist(sv_univ)
# hist(sv_achieve); hist(sv_security); hist(sv_stim); hist(sv_conform)
# hist(sv_trad); hist(sv_hedon); hist(age); hist(lrscale)
# hist(goodpeeps); hist(trust); hist(tvtime); hist(radiotime)
# hist(newspap_time); hist(use_www); hist(scnsenv); hist(rlgdgr)
# hist(attend); hist(pray2); hist(social); hist(meet)
# hist(poli_count); hist(badacts); hist(hwork); hist(careothers_nothh)
# hist(happy); hist(srh); hist(hlth_hamp); hist(bad_exps)
# hist(incomecats); hist(aesfdrk); hist(wgt)
# detach(d)

# variables to log to improve normality
#NOTE: I didn't log careothers_nothh, attend, poli_count, because the transformation didn't change the shape of the distribution much
logvars=c("wgt", "bad_exps", "badacts")
logvars.nowgt=c("bad_exps", "badacts")

# #runs in whole data set for overall diagnostics
# imps.diag = amelia(impvars, m=5, idvars=idvars, logs=logvars)
# plot(imps.diag)
# #seems OK

## perform imputations
#impute variables separately in each country - this preserves any interactions in variables by country country
#need about 40 imputations because highest missing data rate is around 40% for internet use, 36% for ever divorced, or 30% for income
#in some cases the weight is constant within countries - in that case, it must be included as an ID variable

starttime = proc.time()

dtemp=subset(impvars, cntry=="AT")
imps.at=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="BE")
imps.be=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="CH")
imps.ch=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="CZ")
imps.cz=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="DE")
imps.de=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="DK")
imps.dk=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="EE") 
imps.ee=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="ES")
imps.es=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="FI")
imps.fi=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="FR")
imps.fr=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="GB")
imps.gb=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="GR")
imps.gr=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="HU")
imps.hu=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="IE")
imps.ie=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="IS")
imps.is=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="LU")
imps.lu=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="NL")
imps.nl=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="NO")
imps.no=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="PL")
imps.pl=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="PT")
imps.pt=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="SE")
imps.se=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="SI")
imps.si=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="SK")
imps.sk=amelia(dtemp, m=40, idvars=idvars.nowgt, logs=logvars.nowgt)

dtemp=subset(impvars, cntry=="TR")
imps.tr=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

dtemp=subset(impvars, cntry=="UA")
imps.ua=amelia(dtemp, m=40, idvars=idvars, logs=logvars)

endtime=proc.time()
cat("imputation took", (endtime[3] - starttime[3])/60, "minutes")

#combine imputations in each country into one set of imputations - note that unless you have modified the variables used in the imputation for specific countries (e.g., removing a variable for the country), you do not need to sort the columns - the columns are all in the original order, so you can combine the rows directly
#now combine all the datasets together, in the same order as in the original data
imputed.data=list()
for(i in 1:imps.nl$m){
	imputed.data[[i]]=rbind(imps.at$imputations[[i]], imps.be$imputations[[i]], imps.ch$imputations[[i]], imps.cz$imputations[[i]], imps.de$imputations[[i]], imps.dk$imputations[[i]], imps.ee$imputations[[i]], imps.es$imputations[[i]], imps.fi$imputations[[i]], imps.fr$imputations[[i]], imps.gb$imputations[[i]], imps.gr$imputations[[i]], imps.hu$imputations[[i]], imps.ie$imputations[[i]], imps.is$imputations[[i]], imps.lu$imputations[[i]], imps.nl$imputations[[i]], imps.no$imputations[[i]], imps.pl$imputations[[i]], imps.pt$imputations[[i]], imps.se$imputations[[i]], imps.si$imputations[[i]], imps.sk$imputations[[i]], imps.tr$imputations[[i]], imps.ua$imputations[[i]])
	cat(".")
}

#put the combined imputations into an amelia object so you can use functions in the Amelia package
impdata=imps.cz
impdata$imputations = imputed.data
#get a missMatrix that corresponds to the whole sample - note this command is only valid because after sorting and combining, I put the observations and columns back in the same locations in the imputed data matrix as in the original sample
impdata$missMatrix = is.na(impvars)
 
#save.image(file="~/Documents/Job search/Job talk/ESS analyses for job talk/country_imputations.rdata")

## code imputed data

#age categories
impdata=transform(impdata, age20= ifelse(age <=20, 1, 0))
impdata=transform(impdata, age30= ifelse(age > 20 & age <=30, 1, 0))
impdata=transform(impdata, age40= ifelse(age > 30 & age  <=40, 1, 0))
impdata=transform(impdata, age50= ifelse(age > 40 & age  <=50, 1, 0))
impdata=transform(impdata, age60= ifelse(age > 50 & age  <=60, 1, 0))
impdata=transform(impdata, age70= ifelse(age > 60 & age  <=70, 1, 0))
impdata=transform(impdata, age70plus= ifelse(age > 70, 1, 0))

#income categories
impdata=transform(impdata, income6= ifelse(incomecats <=3, 1, 0))
impdata=transform(impdata, income18= ifelse(incomecats > 3 & incomecats <=5, 1, 0))
impdata=transform(impdata, income30= ifelse(incomecats > 5 & incomecats <=7, 1, 0))
impdata=transform(impdata, income60= ifelse(incomecats > 7 & incomecats <=9, 1, 0))
impdata=transform(impdata, income60plus= ifelse(incomecats > 9, 1, 0))

#value variables
impdata=transform(impdata, sv_mean=rowMeans(cbind(ipcrtiv, imprich, ipeqopt, ipshabt, impsafe, impdiff, ipfrule, ipudrst, ipmodst, ipgdtim, impfree, iphlppl, ipsuces, ipstrgv, ipadvnt, ipbhprp, iprspot, iplylfr, impenv, imptrad, impfun)))

#individual value subscales
impdata=transform(impdata, sv_selfd = rowMeans(cbind(ipcrtiv, impfree)) - sv_mean)
impdata=transform(impdata, sv_power = rowMeans(cbind(imprich, iprspot)) - sv_mean)
impdata=transform(impdata, sv_univ = rowMeans(cbind(ipeqopt, ipudrst, impenv)) - sv_mean)
impdata=transform(impdata, sv_achieve = rowMeans(cbind(ipshabt, ipsuces)) - sv_mean)
impdata=transform(impdata, sv_security = rowMeans(cbind(impsafe, ipstrgv)) - sv_mean)
impdata=transform(impdata, sv_stim = rowMeans(cbind(impdiff, ipadvnt)) - sv_mean)
impdata=transform(impdata, sv_conform = rowMeans(cbind(ipfrule, ipbhprp)) - sv_mean)
impdata=transform(impdata, sv_trad = rowMeans(cbind(ipmodst, imptrad)) - sv_mean)
impdata=transform(impdata, sv_hedon = rowMeans(cbind(ipgdtim, impfun)) - sv_mean)
impdata=transform(impdata, sv_benev = rowMeans(cbind(iphlppl, iplylfr)) - sv_mean)
#add these measures to the original data as well
sv_mean=with(d, rowMeans(cbind(ipcrtiv, imprich, ipeqopt, ipshabt, impsafe, impdiff, ipfrule, ipudrst, ipmodst, ipgdtim, impfree, iphlppl, ipsuces, ipstrgv, ipadvnt, ipbhprp, iprspot, iplylfr, impenv, imptrad, impfun), na.rm=T))
d$sv_selfd = with(d, rowMeans(cbind(ipcrtiv, impfree))) - sv_mean
d$sv_power = with(d, rowMeans(cbind(imprich, iprspot))) - sv_mean
d$sv_univ = with(d, rowMeans(cbind(ipeqopt, ipudrst, impenv))) - sv_mean
d$sv_achieve = with(d, rowMeans(cbind(ipshabt, ipsuces))) - sv_mean
d$sv_security = with(d, rowMeans(cbind(impsafe, ipstrgv))) - sv_mean
d$sv_stim = with(d, rowMeans(cbind(impdiff, ipadvnt))) - sv_mean
d$sv_conform = with(d, rowMeans(cbind(ipfrule, ipbhprp))) - sv_mean
d$sv_trad = with(d, rowMeans(cbind(ipmodst, imptrad))) - sv_mean
d$sv_hedon = with(d, rowMeans(cbind(ipgdtim, impfun))) - sv_mean
d$sv_benev = with(d, rowMeans(cbind(iphlppl, iplylfr))) - sv_mean

#value dimensions
#(not shown) - can code the dimensions multiple ways and get nearly identical measures
#this coding used for a sensitivity check later on - it is how Schwartz codes these dimensions at essedunet.nsd.uib.no/cms/topics/1/5/2.html
impdata=transform(impdata, self_trans_measure = rowMeans(cbind(iphlppl, iplylfr, ipeqopt, ipudrst, impenv, -imprich, -iprspot, -ipshabt, -ipsuces)))
impdata=transform(impdata, conserv_measure = rowMeans(cbind(-ipgdtim, -impfun, -impdiff, -ipadvnt, -ipcrtiv, -impfree, impsafe, ipstrgv, ipfrule, ipbhprp, ipmodst, imptrad)))

#coding used in paper
#given hedonism's placement BETWEEN self-direction and stimulation in this sample, include it only in the conservation/openness to change scale
#standardize both scales within countries - that way, we can interpret coefficients in each country in the usual "a 1 SD increase in X leads to a beta increase in Y" fashion
#compare coding to http://essedunet.nsd.uib.no/cms/topics/1/5/2.html
#coding note - I am switching to using lapply() instead of transform() because it is much faster - but this will make it hard to use transform() again since amelia won't recognize the changes made
impdata$imputations=lapply(impdata$imputations, function(x) {x$self_trans_z=std.st.cntry(x); return(x)})
impdata$imputations=lapply(impdata$imputations, function(x) {x$conserv_z=std.c.cntry(x); return(x)})
#add to original data
d$self_trans_z = std.st.cntry(d)
d$conserv_z = std.c.cntry(d)

## Calculate propensity scores for both value dimensions 

#generate propensity scores by country so that the scores in each country reflect the relationships between variables in that country
#to get the necessary predictors in each country do the following:
	#use stepAIC with the AIC (not BIC) to be more conservative and err on the side of keeping more predictors in - this provides better protection against confounding but may inflate SE's in analyses
	#stepAIC will assume that you have all observed data - to get the best estimate of what that observed data would be, take the mean of all the imputed data sets - this should give you accuate point estimates, but SE's won't account for missingness and will be too small - which in the end might just include more variables in the final model, making them conservative
implist=imputationList(impdata$imputations)
data.combined=implist$imputations[[1]]
for(i in 2:length(implist$imputations)){
	data.combined = data.combined + implist$imputations[[i]]
}
#Note: the warning comes from combining the country variable, but it is not used in the pscore analyses so the warning can be ignored
data.combined = data.combined/length(implist$imputations)
nation.list=unique(d$cntry)

#self transcendence
modlist.st=list()
for(i in 1:length(nation.list)){
	modlist.st[[i]]=lm(self_trans_z ~ conserv_z + female + age + ed_upsec + ed_postsec + married + kidshome + city + lrscale + goodpeeps + trust + scnsenv + denom_belong + bad_exps + happy + incomecats + rlgdgr + discrim_group + anydiscuss + hlth_hamp + srh, weights=wgt, data=data.combined, subset=d$cntry==nation.list[[i]])
	modlist.st[[i]]=stepAIC(modlist.st[[i]], direction="both", trace=0)
	if(i %in% seq(0, length(nation.list), by=5)) cat(i) else cat(".")
}

#calcualte propensity scores - traditionally these are converted to probabilities, but this is not necessary as the raw predicted values contain the same information (and ordering)
preds.st.cntry = lapply(modlist.st, predict)
d$st_pred=do.call("c", preds.st.cntry) #note this line only works because data are already in order of countries (i.e., already sorted)

#conservation
modlist.c=list()
for(i in 1:length(nation.list)){
	modlist.c[[i]]=lm(conserv_z ~ self_trans_z + female + age + ed_upsec + ed_postsec + married + kidshome + city + lrscale + goodpeeps + trust + scnsenv + denom_belong + bad_exps + happy + incomecats + rlgdgr + discrim_group + anydiscuss + hlth_hamp + srh, weights=wgt, data=data.combined, subset=d$cntry==nation.list[[i]])
	modlist.c[[i]]=stepAIC(modlist.c[[i]], direction="both", trace=0)
	if(i %in% seq(0, length(nation.list), by=5)) cat(i) else cat(".")
}
#calcualte propensity scores
preds.c.cntry = lapply(modlist.c, predict)
d$cons_pred=do.call("c", preds.c.cntry)

#view pscore model coefficients side-by-side
cfs.st=lapply(modlist.st, coef)
cfs.c=lapply(modlist.c, coef)
nms=unique(c(names(unlist(cfs.st)), names(unlist(cfs.c))))
modmat.st=modmat.c=matrix(NA, nrow=length(nms), ncol=25, dimnames=list(nms, nation.list))
for(i in 1:ncol(modmat.st)){
	modmat.st[match(names(cfs.st[[i]]), rownames(modmat.st)), i]=cfs.st[[i]]
	modmat.c[match(names(cfs.c[[i]]), rownames(modmat.c)), i]=cfs.c[[i]]
}
cat("Propensity score models for self-transcendence")
modmat.st
cat("Propensity score models for conservation")
modmat.c

## create strata variables for hybrid pscore/FE method 

#self-transcendence
#create cutpoints/breakpoints for variable number of divisions, used to get approximately equal strata sizes in each country (where the number of divisions will vary)
nations.n=table(d$cntry)
strata.size=20
d$breaks_selftrans_bynation20peeps=unlist(by(d, d$cntry, makebreaks.st))
strata.size=30
d$breaks_selftrans_bynation30peeps=unlist(by(d, d$cntry, makebreaks.st))
strata.size=25
d$breaks_selftrans_bynation25peeps=unlist(by(d, d$cntry, makebreaks.st))

#conservation
strata.size=20
d$breaks_conserv_bynation20peeps=unlist(by(d, d$cntry, makebreaks.c))
strata.size=30
d$breaks_conserv_bynation30peeps=unlist(by(d, d$cntry, makebreaks.c))
strata.size=25
d$breaks_conserv_bynation25peeps=unlist(by(d, d$cntry, makebreaks.c))

#add the cutpoint variables to the imputated data sets - helps later functions to work right
impdata$imputations=lapply(impdata$imputations, function(x) cbind(x, d[,grep("breaks_", names(d))]))

#generate deviated variables using the cutpoints

#self-transcendence
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=d$breaks_selftrans_bynation20peeps, which.val="st", 20)
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=d$breaks_selftrans_bynation25peeps, which.val="st", 25)
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=d$breaks_selftrans_bynation30peeps, which.val="st", 30)
#now a strata variable that includes everyone in the same stratum (i.e., no strata)
nobreaks=rep(1, dim(d)[1])
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=nobreaks, which.val="st", "_none")

#conservation
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=d$breaks_conserv_bynation20peeps, which.val="c", 20)
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=d$breaks_conserv_bynation25peeps, which.val="c", 25)
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=d$breaks_conserv_bynation30peeps, which.val="c", 30)
nobreaks=rep(1, dim(d)[1])
impdata$imputations=lapply(impdata$imputations, make.devs, breaks.var=nobreaks, which.val="c", "_none")

#remove all objects not needed for further analyses
rm(cfs.c, cfs.st, data.combined, dtemp, endtime, i, idvars, idvars.nowgt, implist, impvars, logvars, logvars.nowgt, missmod.c, missmod.st, modlist.c, modlist.st, modmat.c, modmat.st, nation.list, nations.n, nms, nobreaks, preds.c.cntry, preds.st.cntry, starttime, strata.size)
rm(list=grep("imps.", objects(), value=T, fixed=T))


