#### FUNCTIONS FOR DATA CODING ####

#this function creates the self-transcendence/self-enhancement value dimension in each country
std.st.cntry=function(x){
	g=by(x, x$cntry, function(y) with(y, scale(rowMeans(cbind(iphlppl, iplylfr, ipeqopt, ipudrst, impenv, -imprich, -iprspot, -ipshabt, -ipsuces)))))
	return(unlist(g))
}

#this function creates the conservation/openness to change value dimension in each country
std.c.cntry=function(x){
	g=by(x, x$cntry, function(y) with(y, scale(rowMeans(cbind(-ipgdtim, -impfun, -impdiff, -ipadvnt, -ipcrtiv, -impfree, impsafe, ipstrgv, ipfrule, ipbhprp, ipmodst, imptrad)))))
	return(unlist(g))
}

#function to create the appropriate number of strata in a country, given a set strata size, for self-transcendence
makebreaks.st=function(x){
	breaknum=round(nations.n/strata.size)
	whichcntry=unique(x$cntry)
	breaks=quantile(x$st_pred, probs=seq(from=0, to=1, by=1/breaknum[whichcntry]))
	strata=cut(x$st_pred, breaks=breaks, include.lowest=T, labels=F)
	#if missing because larger than the maximum strata value, put in top stratum
	strata=ifelse(is.na(strata) & x$st_pred > max(breaks), max(strata, na.rm=T), strata)
	#if missing because lower than the minimum strata value, put in lowest stratum
	strata=ifelse(is.na(strata) & x$st_pred < min(breaks), min(strata, na.rm=T), strata)
	paste(whichcntry,strata, sep="")
}

#function to create the appropriate number of strata in a country, given a set strata size, for conservation
makebreaks.c=function(x){
	breaknum=round(nations.n/strata.size)
	whichcntry=unique(x$cntry)
	breaks=quantile(x$cons_pred, probs=seq(from=0, to=1, by=1/breaknum[whichcntry]))
	strata=cut(x$cons_pred, breaks=breaks, include.lowest=T, labels=F)
		#if missing because larger than the maximum strata value, put in top stratum
	strata=ifelse(is.na(strata) & x$cons_pred > max(breaks), max(strata, na.rm=T), strata)
	#if missing because lower than the minimum strata value, put in lowest stratum
	strata=ifelse(is.na(strata) & x$cons_pred < min(breaks), min(strata, na.rm=T), strata)
	paste(whichcntry,strata, sep="")
}

#function to create deviated variables
make.devs=function(x, breaks.var, which.val, peeps.per.stratum){
	which.val.dev=switch(which.val, st="self_trans", c="cons")
	which.val.assign=switch(which.val, st="self_trans_z", c="conserv_z")
	mean.name=paste(which.val, "_strata_mean", peeps.per.stratum, sep="")
	dev.name=paste(which.val.dev, "_dev", peeps.per.stratum, sep="")
	x[,mean.name]=ave(x[,which.val.assign], breaks.var)
	x[,dev.name]=x[,which.val.assign]-x[,mean.name]
	return(x)
}

#### FUNCTIONS FOR ANALYSES ####

#this function combines estimates fit to multiply imputed data sets - it gives the pooled estimate and SE if variance information is given, or just the pooled estimate otherwise

MIcombine2=function(results, variances, call = sys.call(), df.complete = Inf, ...){
	modtype="notamod"
	if (missing(variances)) {
		#first check to see why the variances are missing - is this a fitted model, or were the variances left out on purpose?
        modtype=switch(class(results[[1]])[1], lm="lm", glm="glm", lavaan="sem", mer="lmer", polr="polr", sclm="clm", "notamod")
        if(modtype %in% c("lm", "glm", "sem", "clm")) {
        	results.list=results
        	variances <- suppressWarnings(lapply(results, vcov))
        	results <- lapply(results, coef)
        }
        if(modtype %in% c("lmer")) {
        	results.list=results
        	variances <- suppressWarnings(lapply(results, vcov))
        	results <- lapply(results, fixef)
        	#need a way to get the point estimate of the REs and their SE's
        }
        if(modtype %in% c("polr")){
        	if(is.null(results[[1]]$Hessian)) stop("please refit the polr model with Hessian=TRUE")
        	results.list=results
        	variances = suppressWarnings(lapply(results, vcov))
        	results = lapply(results, function(x) summary(x)$coefficients[,"Value"])
        }
    }  #end missing(variances) statement
    if(modtype=="notamod") MIcombine.internal(results, noSE=T, results.list=NULL, ...) else
    	MIcombine.internal(results, variances, results.list=results.list, ...)
}  #end function MIcombine2


MIcombine.internal=function (results, variances, results.list=results.list, noSE=F, call = sys.call(), df.complete = Inf, ...) 
{
    m <- length(results)
    oldcall <- attr(results, "call")
    if(noSE==F) vbar <- variances[[1]]
    cbar <- results[[1]]
    for (i in 2:m) {
        cbar <- cbar + results[[i]]
        if(noSE==F) vbar <- vbar + variances[[i]]
    }
    cbar <- cbar/m
    if(noSE==F) {
    	vbar <- vbar/m
    	evar <- var(do.call("rbind", results))
    	r <- (1 + 1/m) * evar/vbar
    	df <- (m - 1) * (1 + 1/r)^2
    	if (is.matrix(df)) 
        	df <- diag(df)
    	if (is.finite(df.complete)) {
        	dfobs <- ((df.complete + 1)/(df.complete + 3)) * df.complete * 
            vbar/(vbar + evar)
        if (is.matrix(dfobs)) 
            dfobs <- diag(dfobs)
        df <- 1/(1/dfobs + 1/df)
    	}
    	if (is.matrix(r)) 
        	r <- diag(r)
    	rval <- list(coefficients = cbar, variance = vbar + evar * 
        (m + 1)/m, call = c(oldcall, call), nimp = m, df = df, 
        missinfo = (r + 2/(df + 3))/(r + 1))
    }
    if(noSE) rval= list(coefficients=cbar, nimp = m)
    if(noSE==F) class(rval) <- "MIresult"
    rval$MI.estimates=results.list
    rval
}

#this function takes an imputed data set and calculates correlations between factor scores to coding of value dimensions used in paper
getcors=function(x){
	factmod=with(x, fa(cbind(ipcrtiv, imprich, ipeqopt, ipshabt, impsafe, impdiff, ipfrule, ipudrst, ipmodst, ipgdtim, impfree, iphlppl, ipsuces, ipstrgv, ipadvnt, ipbhprp, iprspot, iplylfr, impenv, imptrad, impfun), nfactors=3, rotate="none"))
	conserv=factmod$scores[,2]  #remember 1st factor is a methods factor
	selftrans=factmod$scores[,3]
	cat(".")
	cor(cbind(conserv, selftrans, cons=x$conserv_measure, selft=x$self_trans_measure))
}

#this function takes an imputed data set and calculates a non-metric multi-dimensional scaling solution for the 10 value categories
get.mds=function(x){
	mat=with(x, cbind(sv_benev, sv_hedon, sv_trad, sv_conform, sv_stim, sv_security, sv_achieve, sv_univ, sv_power, sv_selfd))
	dists=dist(t(mat))
	mod=sammon(dists, k=2, trace=F)
	return(mod$points/10)
}

#this function takes a character vector of variable names, the name of a variable to compare them to (character), and examines the correlation between them within each stratum (specificed by strata.var), returning the t-statistic of the test of whether the correlation is significantly different from 0 - if you specify avg.t, the average t-statistic across all strata is returned instead, weighted by strata size
#you can also ask for polyserial correlations using ordered=T, but this will throw an error if there is no variation in one of the variables
#note that this IS valid for the dichotomous variables, since it just gives you a t-test (assuming equal variances) of self.trans divided by the binary variable
check.cor=function(vars, strata.var, data, compare.var, verbose=T, avg.t=T, ordered=F) {
	require(Hmisc)
	strata.list=list()
	strata.size=c()
	levs=unique(data[,strata.var])
	#construct a list with data from each stratum in each list element
	if(verbose) cat("creating a list of data in each stratum")
	for(i in 1:length(levs)){
		ind = which(data[,strata.var] %in% levs[i])
		strata.list[[i]] = data[ind,c(vars, compare.var)]
		strata.size=c(strata.size, dim(strata.list[[i]])[1])
	}
	if(verbose) cat("-FINISHED", "\n")
	#an internal function that will examine the correlation of the compare.var to each variable in var
	checkcor.internal=function(dat, vars, compare.var, ordered) {	
		comparevar=dat[,compare.var]
		dat=dat[,vars]
		#print(summary(comparevar)); print(summary(dat))
		if(!ordered) toreturn=apply(dat, 2, FUN=function(x) cor.test(x=x, y=comparevar, use="complete.obs")$statistic)
		if(ordered) {
			ordered.test=function(x, comparevar) {
				poly.cor=polyserial(x, comparevar, std.err=T)
      			poly.cor$rho/sqrt(poly.cor$var)   #t-value: corr over the SE of corr
			} #end ordered.test()
			toreturn=apply(dat, 2, FUN=function(x) ordered.test(x=x, comparevar=comparevar))
		} #end if(ordered)
		return(toreturn)
	} #end checkcor.internal
	#calculate the correlation between compare.var and each variable in var for every stratum (every element of strata.list)
	if(verbose) cat("calculating correlation t-values in each stratum")
	tvals=sapply(strata.list, checkcor.internal, compare.var=compare.var, vars=vars, ordered=ordered)
	if(verbose) cat("-FINISHED", "\n")
	if(avg.t) apply(abs(tvals),1, wtd.mean, weights=strata.size)
		else t(tvals)
}  #end check.cor()

# this function is a general-purpose model summary function that I am continually updating - it is called internally by one of the other functions, so I am including it here, though much of its functionality is never used in this project
mod.summary = function(model, white.adjust=c("none", "const", "HC3", "HC0", "HC1", "HC2", "HC4", "cluster"), cluster=NULL, std.coef=c("none", "beta", "y", "mix", "robust"), bic=TRUE, odds=FALSE, CI=FALSE, CIlevel=0.95, logit.tools=T, verbose=T, ...) {

#function to estimate the variance of the latent variable underlying a binary or ordinal logit outcome
#note: results differ slightly from listcoef command in fitstat, and a little more when there are weights (but I think it is because listcoef converts pweights to aweights)
estyvar=function(m, ...) {
		#adapted from fitstat in Stata
		#modtype=class(m)[1]
		#if(modtype=="glm") modtype=family(m)$link
		mod.matrix=switch(modtype, ologit=model.matrix(m$terms, data=m$model), oprobit=model.matrix(m$terms, data=m$model), ologit.clm=model.matrix(m$terms, data=m$model), model.matrix(m$formula, data=m$model))
		#are there any weights?
		if("(weights)" %in% colnames(m$model)){
			w = m$model[,"(weights)"]
		} else
		w = 1
		#this makes all data deviated from its mean
		mod.matrix=apply(mod.matrix,2,function(x) {x-mean(x)})
		new.n=dim(mod.matrix)[1]-1
		#get the X matrix without the intercept
		mod.matrix=mod.matrix[,colnames(mod.matrix)!="(Intercept)"]
		require(car)
		#note the crossprod is just giving you t(X) %*% X
		Vx = wcrossprod(mod.matrix, mod.matrix, w)/new.n
		#adjust for single variable models where the matrix becomes a vector
		if(class(Vx)=="numeric") Vx = matrix(Vx, nrow=1) 
		#explained variance (variance of the linear predictor), make sure there is no intercept
		b=switch(modtype, ologit.clm=m$beta, coef(m))
		b=b[names(b)!="(Intercept)"]
		#t(b) gives a row vector, and t(t(b)) gives a column vector
		ss.ex=t(b) %*% Vx %*% t(t(b))
		#error variance, assumed to be 3.29 in logit models, 1 in probit
		sse = switch(modtype, ologit=pi^2/3, ologit.clm=pi^2/3, logit=pi^2/3, probit=1, oprobit=1)
		totalvar=ss.ex + sse
		if(verbose) print(paste("SD of latent variable", round(sqrt(as.numeric(totalvar)), 4), sep=": "))
		return(as.numeric(totalvar))
}

#standardized, y-standardized, and robust regression coefficients - assumes your model has an intercept
coeffs=function(MOD, type, mod.sumry, ...)
	{
		#get the model matrix (this handles any categorical variable correctly)
    dat=as.data.frame(model.matrix(MOD$terms, data=MOD$model))
    b = switch(modtype, lm=summary(MOD)$coef[-1,1], logit=summary(MOD)$coef[-1,1], ologit=coef(MOD), oprobit=coef(MOD), probit=coef(MOD)[-1], ologit.clm=MOD$beta)
		se = switch(modtype, lm=sqrt(diag(mod.sumry$vcov))[-1], logit=sqrt(diag(mod.sumry$vcov))[-1], probit=sqrt(diag(mod.sumry$vcov))[-1], ologit=sqrt(diag(vcov(mod.sumry)))[1:length(coef(MOD))], oprobit=sqrt(diag(vcov(mod.sumry)))[1:length(coef(MOD))], ologit.clm=sqrt(diag(mod.sumry$vcov))[(length(MOD$alpha)+1):length(coef(MOD))])
		if(type!="y") sx = apply(dat[-1], 2, sd)
		sy = switch(modtype, lm=apply(MOD$model[1], 2, sd), logit=sqrt(estyvar(MOD, ...)), probit=sqrt(estyvar(MOD, ...)), ologit=sqrt(estyvar(MOD, ...)), oprobit=sqrt(estyvar(MOD, ...)), ologit.clm=sqrt(estyvar(MOD, ...)))
		if(type=="beta") {beta = b * sx/sy; ses=se*(sx/sy)}
		if(type=="y") {beta = b/sy; ses=se/sy}
    		if(type=="mix") {
	      get.uniques=sapply(dat[-1], unique, simplify=FALSE)
	      lengths=sapply(get.uniques, length)
	      max1=sapply(get.uniques, max)
	      min0=sapply(get.uniques, min)
	      is.binary=lengths==2 & max1==1 & min0==0
	      beta = ifelse(is.binary, b/sy, b * sx/sy)
	      ses = ifelse(is.binary, se/sy, se*(sx/sy))
    		}
		if(type=="robust"){
			sx <- sapply(MOD$model[-1], IQR)
    			sy <- sapply(MOD$model[1], IQR)
    			beta <- b * sx/sy
    			ses=se*(sx/sy)
		}
		return(cbind(beta, ses))
	}

#Confidence intervals - I have to include this because the built in function confint() won't use corrected vcov matrices
confints=function(object, parm, level = 0.95, ...)
	{
    	cf <- object$coef[,1]
    	pnames <- names(cf)
    	if (missing(parm)) 
        	parm <- pnames
    	a <- (1 - level)/2
    	a <- c(a, 1 - a)
    	pct = paste(round(100 * a, 1), "%")
      	fac <- qt(a, object$df[2])
    	ci <- array(NA, dim = c(length(parm), 2L), dimnames = list(parm, pct))
    	ses <- sqrt(diag(object$vcov))[parm]
    	ci[] <- cf[parm] + ses %o% fac
    	ci
	}

#Corrected vcov matrices based on clustering (rather than just assuming a generic approach like HC0 or HC3)
clx = function(fm, dfcw, cluster){
         # R-codes (www.r-project.org) for computing
         # clustered-standard errors. Mahmood Arai, Jan 26, 2008.
	 # The arguments of the function are:
         # fitted model, degree of freedom correction (not used in my implementation) and cluster) 
         # reweighting the var-cov matrix for the within model (i.e. the meat part of the sandwhich matrix)
         #first make sure you have the same observations in your cluster variable that were used in the fitted model
         if(length(cluster) != length(unlist(labels(fm$model)[1]))) cluster.mod = cluster[as.numeric(unlist(labels(fm$model)[1]))]
         else cluster.mod=cluster
         M <- length(unique(cluster.mod))   
         N <- length(cluster.mod)          
         K <- fm$rank                        
         dfc <- (M/(M-1))*((N-1)/(N-K))  #finite sample adjustment
         uj  <- apply(estfun(fm),2, function(x) tapply(x, cluster.mod, sum))  #i.e. summing within each unique level of cluster.mod for each row in the matrix containing the empirical estimating functions of the fitted model
         #NOTE: the crossprod() is equivalent to sum(u*t(u)), i.e. the sum of the vector created by u*transpose(u)
         vcovCL <- dfc*sandwich(fm, meat=crossprod(uj)/N)*dfcw
	}

#Warnings and data checks	
	if(odds) {
		if (class(model)[1] != "glm") stop("Fitted model must of class 'glm' in order to use odds ratios")
		if (model$family$link != "logit") stop("Cannot produce odds ratios, model is not a logistic regression")
	}
	if(!require(sandwich)) stop("Required sandwich package is missing")
	if(!require(lmtest)) stop("Required lmtest package is missing")
	if(match.arg(white.adjust)=="cluster") if(is.null(cluster)) stop("Must specify a variable representing hetero. clustering to use the 'cluster' option in white.adjust")

#type of model
modtype=class(model)[1]
if(modtype=="glm") modtype=model$family$link
if(modtype=="polr") modtype=switch(model$method, logistic="ologit", probit="oprobit")
if(modtype=="sclm" | modtype=="clm") {modtype="ologit.clm"; model$rank=model$edf}

#Calculating vcov matrix for SEs
	adjust=match.arg(white.adjust)
	if(adjust=="none") V = vcov(model)
	if(adjust=="cluster") V = clx(model, 1, cluster)
	if((adjust != "none") & (adjust != "cluster")) V = vcovHC(model, type=adjust)
	
#Building the summary object
	sumry = summary(model)
	table = coeftest(model, vcov=V)
	sumry$cov.scaled=sumry$vcov=V

#drop weights from model matrix if there are any - allows the standardization functions to run as they are currently written
if("(weights)" %in% names(model$model)) {
	model$model = model$model[-which(names(model$model)=="(weights)")]
}

#Update coefficients based on specified options	
	if(CI) {
#if you can just change the relevant features of a model object, you can use the built in functions confint() and not have to rewrite them - i.e. you need to change the vcov matrix that the confint() functions get
		table2 = confints(sumry, level=CIlevel)
		if(odds) table2=exp(table2)
		if (match.arg(std.coef)!="none")
		{
			cimod=model
			for(i in 1:2)
			{
				cimod$coefficients=table2[,i]
				table2[,i]=c(NA,coeffs(cimod, std.coef)[,1])
			}
		} 
		sumry$confint=table2
	} #end if statement for confident intervals
	#modify this so that it uses corrected SEs
	if (match.arg(std.coef)!="none") {
		if(modtype %in% c("lm", "logit", "probit")) {
      		table[,c(1,2)]= rbind(rep(NA, 2), coeffs(model, std.coef, sumry, ...))
			table[1,] = rep(NA, 4)
			}
		if(modtype %in% c("ologit", "oprobit")) table[,c(1,2)]= coeffs(model, std.coef, sumry, ...)
		if(modtype == "ologit.clm") {
			table[(length(model$alpha)+1):length(coef(model)), c(1,2)] = coeffs(model, std.coef, sumry, ...)
			table[1:length(model$alpha),]=NA
			}
		nms=colnames(table)
		nms[1]=switch(std.coef, beta="Std. coef", y="y-std. coef", mix="Mixed y/std. coef", robust="Robust coef")
		colnames(table)=nms
	} #end if statement for std.coef
	if(odds) {
		nms=colnames(table)
		nms=c(nms[1], "Odds ratio", nms[2:4])
		table=cbind(table[,1], exp(coef(model)), table[,2:4])		
		colnames(table)=nms
	} #end if statement for odds	
	sumry$coefficients = table
#additional information to attach to summary object
	sumry$bic = AIC(model, k=log(length(model$fitted.values)))
#add extra fit information for logit regressions
if(modtype=="logit" & logit.tools==T){
	#requires my function logit.tools
	source('~/Documents/R code/logit.tools.R', chdir = TRUE)
	sumry$logit.fit = logit.tools(model, verbose=F, ...)
}

#information for printing
if(verbose){
	cat("Information about displayed results", "\n")
	if(bic) {
		cat("BIC: ", sumry$bic, "\n")
	}
	if(odds) cat("Odds ratios used", "\n")
	if((adjust != "const") & (adjust != "none"))  cat("Note: Heteroscedasticity-consistent SEs using adjustment", adjust, "\n")
	if(match.arg(std.coef)=="beta") cat("Note: Standardized regression coefficients/SEs used", "\n")
	if(match.arg(std.coef)=="robust") cat("Note: Robust standardized regression coefficients/SEs used", "\n")
	if(match.arg(std.coef)=="y") cat("Note: y-standardized regression coefficients/SEs used", "\n")
  if(match.arg(std.coef)=="mix") cat("Note: Standardized regression coefficients/SEs used for non-binary predictors", "\n", "y-standardized regression coefficients/SEs used for binary predictors", "\n")
	if(CI) {
		cat("\n")
		cat(CIlevel*100,"% confidence intervals", "\n")
		print(table2)
		}
} #end if(verbose) statement
			return(sumry)
} #end of mod.summary()


#this function will take m fitted models (where m is the number of imputations), and generate cluster-robust standard errors, where the cluster is defined by the pscore strata variable provied in strata.var, and will also provide y-standardized coefficients - y-standardization is used because the country predictors are dichtomous, and the values predictors are already standardized
#to obtain unstandardized coefficients, change the "y" argument for std.coef to "none"
modify.model=function(modlist, strata.var, std.coef="none", white.adjust) {
	ind=as.integer(rownames(modlist[[1]]$model))  #to get just the observations used in the analysis
	for(i in 1:length(modlist)){
		modlist[[i]]=mod.summary(modlist[[i]], logit.tools=F, verbose=F, std.coef=std.coef, white.adjust=white.adjust, cluster=implist$imputations[[i]][ind, strata.var])
		if (i %in% printnums) cat(i) else cat(".")
	}
	return(modlist)
} #end modify.model()


reg.bycntry=function(outcome, pred, strata.mean, regtype=c("lm", "logit", "nb"), white.adjust="cluster", ...){
	regtype=match.arg(regtype)
	cntry.list=as.character(unique(d$cntry))
	notmiss=!is.na(d[,outcome])
	form=formula(paste(outcome, pred, sep="~"))
	modlist=list()
	for(i in 1:length(cntry.list)){
		cat("\n", cntry.list[[i]])
		if(regtype=="lm") modlist[[i]]=lapply(implist$imputations, function(x) lm(form, weight=wgt, subset=notmiss & cntry==cntry.list[[i]], data=x))
		if(regtype=="logit") modlist[[i]]=lapply(implist$imputations, function(x) glm(form, weight=wgt, subset=notmiss & cntry==cntry.list[[i]], data=x, family=binomial(link="logit")))
		if(regtype=="nb") modlist[[i]]=lapply(implist$imputations, function(x) glm.nb(form, weight=wgt, subset=notmiss & cntry==cntry.list[[i]], data=x))
		modlist[[i]]=modify.model(modlist[[i]], strata.mean, white.adjust, ...)
		modlist[[i]] = MIcombine(lapply(modlist[[i]], function(x) {coef(x)[,1]}), lapply(modlist[[i]], function(x) coef(x)[,2]^2))
	}
	names(modlist)=cntry.list
	return(modlist)
} #end reg.bycntry()

#this function calculates p-values from pooled MI models
get.p=function(x, whichval){
	coefs=coef(x)[whichval]
	ses=sqrt(diag(vcov(x)))[whichval]
	z=coefs/ses
	2*pnorm(abs(z), lower.tail=F)
}


cntrl.bycntry=function(outcome, regtype=c("lm", "logit", "nb", "ologit"), ...) {
	regtype=match.arg(regtype)
	cntry.list=as.character(unique(d$cntry))
	notmiss=!is.na(d[,outcome])
	form=formula(paste(outcome, "female + age + ed_upsec + ed_postsec + married + kidshome + city + lrscale + goodpeeps + trust + scnsenv + denom_belong + bad_exps + happy + incomecats + rlgdgr + discrim_group + anydiscuss + hlth_hamp + srh", sep="~"))
	modlist=list()
	for(i in 1:length(cntry.list)){
		cat("\n", cntry.list[[i]])
		if(regtype=="lm") modlist[[i]]=lapply(implist$imputations, function(x) lm(form, weight=wgt, subset=notmiss & cntry==cntry.list[[i]], data=x))
		if(regtype=="logit") modlist[[i]]=lapply(implist$imputations, function(x) glm(form, weight=wgt, subset=notmiss & cntry==cntry.list[[i]], data=x, family=binomial(link="logit")))
		if(regtype=="nb") modlist[[i]]=lapply(implist$imputations, function(x) glm.nb(form, weight=wgt, subset=notmiss & cntry==cntry.list[[i]], data=x))
		if(regtype=="ologit") modlist[[i]]=lapply(implist$imputations, function(x) clm(form, weight=wgt, subset=notmiss & cntry==cntry.list[[i]], data=x))
		modlist[[i]]=modify.model(modlist[[i]], white.adjust="none", ...)
		modlist[[i]] = MIcombine(lapply(modlist[[i]], function(x) {coef(x)[,1]}), lapply(modlist[[i]], function(x) coef(x)[,2]^2))
	} #end i loop
	names(modlist)=cntry.list
	return(modlist)
} #end cntrl.bycntry()

sig.cfs=function(mimod){
	cfs=coef(mimod)
	ses=sqrt(diag(vcov(mimod)))
	zvals=cfs/ses
	mimod$coefficients[abs(zvals) < 1.96]=NA
	return(abs(mimod$coefficients))
}

#note I have already included the cluster robust SE's in the vcov of the pooled model
get.margeffs=function(mi.mod, dydx.var, cntry.names){	
	calc.dydx=function(dydx.var, cntry, mi.mod) {
		s[1:length(s)]=0
		int=paste(dydx.var, paste("cntry", cntry, sep=""), sep=":")
		s[c(dydx.var, int)]=1
		me.name = paste("me", tolower(cntry), sep=".")
		se.name = paste("se", tolower(cntry), sep=".")
		assign(me.name, s %*% cfs, pos=newenv)
		assign(se.name, sqrt(s %*% vcov(mi.mod) %*% s), pos=newenv)
	} #end calc.dydx()
	newenv=environment()
	cfs=s=coef(mi.mod)
	#this line replaces missing values - assumed for the intercept - (which you get if you standardize coefficients using mod.summary() before calculating marginal effects) with 0 - this allows the matrix multiplication to work, but doesn't change the calculation since the intercepts are not used in calculating linear marginal effects
	cfs[is.na(cfs)]=0
	assign("me.at", cfs[dydx.var], envir=newenv)
	assign("se.at", sqrt(vcov(mi.mod)[dydx.var, dydx.var]), envir=newenv)
	mods=list()
	for(i in 1:length(cntry.names)){
		mods[[i]]=mi.mod
	}
	mapply(calc.dydx, rep(dydx.var, length(cntry.names)), cntry.names, mods)
	margeffs=do.call("cbind", list(mget(grep("me.", objects(), fixed=T, value=T), envir=newenv)))
	margeffs.se=do.call("cbind", list(mget(grep("se.", objects(), fixed=T, value=T), envir=newenv)))
	data.frame("Marginal effects"=unlist(margeffs), "SE"=unlist(margeffs.se))
} #end get.margeffs()